<template>
  <div class="search">
    <el-form
      style="width:100%"
      ref="form"
      label-width="auto"
    >
      <div class="search-child"
           v-for="(item, index) in searchData"
           :key="index">
        <el-form-item v-if="item.type == '输入框'" :label="item.label + ':'">
          <el-input
            v-model="item.value"
            clearable
            :placeholder="'请输入' + item.label"
            @input="inputItem(item.value, index)"
            size="small"
          ></el-input>
        </el-form-item>

        <el-form-item v-if="item.type === '单选框'" :label="item.label + ':'">
          <el-radio-group v-model="item.value">
            <el-radio
              v-for="(items, indexs) in item.optionsArr"
              :key="indexs"
              :label="items.value"
              @click.native.prevent="clickItem(items.value, item.value, index)"
            >{{ items.name }}
            </el-radio
            >
          </el-radio-group>
        </el-form-item>

        <el-form-item v-if="item.type == '日期'" :label="item.label + ':'">
          <el-date-picker
            clearable
            v-model="item.value"
            type="daterange"
            range-separator="至"
            start-placeholder="开始日期"
            end-placeholder="结束日期"
            value-format="yyyy-MM-dd"
            @change="daterangeItem(item.value, index)"
          >
          </el-date-picker>
        </el-form-item>

        <el-form-item v-if="item.type == '多选框'" :label="item.label + ':'">
          <el-checkbox-group v-model="item.value">
            <el-checkbox
              v-for="(items, indexs) in item.optionsArr"
              :key="indexs"
              :label="items.value"
              @change="checkboxItem(items.value, item.value, index)"
            >{{ items.name }}
            </el-checkbox
            >
          </el-checkbox-group>
        </el-form-item>
      </div>

    </el-form>
  </div>
</template>

<script>
export default {
  props: {
    searchData: {
      default: [],
      type: Array
    }
  },
  data() {
    return {
      checkList: [],
      searchForm: {},
      resource: '',
      cardTypeData: [
        {
          name: '营业执照',
          value: 0
        },
        {
          name: '身份证',
          value: 1
        },
        {
          name: '驾驶证',
          value: 2
        },
        {
          name: '军官证',
          value: 3
        },
        {
          name: '护照',
          value: 4
        }
      ]
    }
  },
  methods: {
    daterangeItem(item, index) {
      if (item == null) {
        item = ''
      }
      this.$emit('searchChild', {
        value: item,
        index: index
      })
    },
    inputItem(item, index) {
      this.$emit('searchChild', {
        value: item,
        index: index
      })
    },
    checkboxItem(value, item, index) {
      this.$emit('searchChild', {
        value: item,
        index: index
      })
    },
    clickItem(value, item, index) {
      if (value === item) {
        this.searchData[index].value = '' //如果点击的对象是area就将v-model的值清空 radio状态为空
      } else {
        this.searchData[index].value = value //否则就把点击的值赋值给area 即绑定的radio
      }
      this.$emit('searchChild', {
        value: this.searchData[index].value,
        index: index
      })
    }
  }
}
</script>

<style lang="scss" scoped>
.search {
  width: 100%;
  line-height: 40px;
}

/deep/ .el-form-item {
  width: 100%;
}

/deep/ .el-input {
  width: 16%;
}

/deep/ .el-radio__input {
  display: none;
}

/deep/ .el-checkbox__input {
  display: none;
}

/deep/ .el-form-item__content {
  line-height: 40px;
}

/deep/ .el-form-item__label-wrap {
  line-height: 40px;
}

::v-deep .el-radio__label {
  color: #888;
}
</style>
